@@ -1,8 +1,9 @@
 # coding=utf-8
 
-from PyQt4 import QtGui, QtCore, Qt
-from PyQt4.Qt import QMainWindow, QWidget, QHBoxLayout, QVBoxLayout, \
-                     QLineEdit, QPushButton, QTableView, SIGNAL, QUrl
+from PyQt4 import QtGui, QtCore
+from PyQt4.QtCore import SIGNAL, QUrl
+from PyQt4.QtGui import QMainWindow, QWidget, QHBoxLayout, QVBoxLayout, \
+                     QLineEdit, QPushButton, QTableView,QGridLayout
 
 import sys
 import traceback
@@ -34,13 +35,40 @@ class SMMainWindow(QMainWindow):
         self.vbox.addWidget(self.lineEdit)
         self.vbox.addWidget(self.lookupButton)
         self.vbox.addWidget(self.openUrlButton)
+        self.numPad = QGridLayout()
+        gridHSpacing = 0
+        self.numPad.setHorizontalSpacing(gridHSpacing)
+        singleButtonWidth = 58
+        button1 = self.createNumKey("1", singleButtonWidth)
+        button2 = self.createNumKey("2", singleButtonWidth)
+        button3 = self.createNumKey("3", singleButtonWidth)
+        button4 = self.createNumKey("4", singleButtonWidth)
+        button5 = self.createNumKey("5", singleButtonWidth)
+        button6 = self.createNumKey("6", singleButtonWidth)
+        button7 = self.createNumKey("7", singleButtonWidth)
+        button8 = self.createNumKey("8", singleButtonWidth)
+        button9 = self.createNumKey("9", singleButtonWidth)
+        button0 = self.createNumKey("0", 2 * singleButtonWidth + gridHSpacing)
+        buttonCE = self.createNumKey("CE", singleButtonWidth)
+        self.numPad.addWidget(button7, 0, 0, 1, 1)
+        self.numPad.addWidget(button8, 0, 1, 1, 1)
+        self.numPad.addWidget(button9, 0, 2, 1, 1)
+        self.numPad.addWidget(button4, 1, 0, 1, 1)
+        self.numPad.addWidget(button5, 1, 1, 1, 1)
+        self.numPad.addWidget(button6, 1, 2, 1, 1)
+        self.numPad.addWidget(button1, 2, 0, 1, 1)
+        self.numPad.addWidget(button2, 2, 1, 1, 1)
+        self.numPad.addWidget(button3, 2, 2, 1, 1)
+        self.numPad.addWidget(button0, 3, 0, 1, 2)
+        self.numPad.addWidget(buttonCE, 3, 2, 1, 1)
+        self.vbox.addLayout(self.numPad)
 #        self.vbox.addWidget(self.hkCheckbox)
         self.vbox.addStretch()
 
         self.model = StockMatchTableModel()
         self.table = QTableView()
         self.table.setModel(self.model)
-        self.table.setMinimumWidth(480)
+        self.table.setMinimumWidth(580)
         self.table.setWordWrap(False)
         self.table.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
         self.table.horizontalHeader().setStretchLastSection(True)
@@ -62,6 +90,31 @@ class SMMainWindow(QMainWindow):
                      SIGNAL("selectionChanged(QItemSelection, QItemSelection)"),
                      self.entrySelected)
         self.connect(self.openUrlButton, SIGNAL("pressed()"), self.openUrl)
+        self.connect(button0, SIGNAL("pressed()"), lambda: self.pressedNum(0) )
+        self.connect(button1, SIGNAL("pressed()"), lambda: self.pressedNum(1) )
+        self.connect(button2, SIGNAL("pressed()"), lambda: self.pressedNum(2) )
+        self.connect(button3, SIGNAL("pressed()"), lambda: self.pressedNum(3) )
+        self.connect(button4, SIGNAL("pressed()"), lambda: self.pressedNum(4) )
+        self.connect(button5, SIGNAL("pressed()"), lambda: self.pressedNum(5) )
+        self.connect(button6, SIGNAL("pressed()"), lambda: self.pressedNum(6) )
+        self.connect(button7, SIGNAL("pressed()"), lambda: self.pressedNum(7) )
+        self.connect(button8, SIGNAL("pressed()"), lambda: self.pressedNum(8) )
+        self.connect(button9, SIGNAL("pressed()"), lambda: self.pressedNum(9) )
+        self.connect(buttonCE, SIGNAL("pressed()"), self.pressedCE)
+
+    def pressedCE(self):
+        self.lineEdit.clear()
+
+    def pressedNum(self, num):
+        old = self.lineEdit.text()
+        numStr = str(num)
+        self.lineEdit.setText(old + numStr)
+
+    def createNumKey(self, numStr, width):
+        btn = QPushButton(numStr)
+#        btn.setMinimumWidth(width)
+        btn.setMaximumWidth(width)
+        return btn
 
     def processNewQuery(self):
         queryString = self.lineEdit.text()
